@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -243,6 +243,13 @@ photos_base_manager_default_get_previous_object (PhotosBaseManager *self, GObjec
 }
 
 
+static PhotosSparqlTemplate *
+photos_base_manager_default_get_sparql_template (PhotosBaseManager *self, gint flags)
+{
+  return NULL;
+}
+
+
 static gchar *
 photos_base_manager_default_get_where (PhotosBaseManager *self, gint flags)
 {
@@ -437,6 +444,7 @@ photos_base_manager_class_init (PhotosBaseManagerClass *class)
   class->get_next_object = photos_base_manager_default_get_next_object;
   class->get_object_by_id = photos_base_manager_default_get_object_by_id;
   class->get_previous_object = photos_base_manager_default_get_previous_object;
+  class->get_sparql_template = photos_base_manager_default_get_sparql_template;
   class->get_where = photos_base_manager_default_get_where;
   class->remove_object_by_id = photos_base_manager_default_remove_object_by_id;
   class->set_active_object = photos_base_manager_default_set_active_object;
@@ -694,6 +702,14 @@ photos_base_manager_get_previous_object (PhotosBaseManager *self, GObject *objec
 }
 
 
+PhotosSparqlTemplate *
+photos_base_manager_get_sparql_template (PhotosBaseManager *self, gint flags)
+{
+  g_return_val_if_fail (PHOTOS_IS_BASE_MANAGER (self), NULL);
+  return PHOTOS_BASE_MANAGER_GET_CLASS (self)->get_sparql_template (self, flags);
+}
+
+
 const gchar *
 photos_base_manager_get_title (PhotosBaseManager *self)
 {
