@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2014 – 2019 Red Hat, Inc.
+ * Copyright © 2014 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -149,6 +149,9 @@ photos_create_collection_icon_job_run (PhotosCreateCollectionIconJob *self,
 {
   g_autoptr (GTask) task = NULL;
 
+  g_return_if_fail (PHOTOS_IS_CREATE_COLLECTION_ICON_JOB (self));
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
+
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_create_collection_icon_job_run);
 
