@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 – 2019 Red Hat, Inc.
+ * Copyright © 2013 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -169,6 +169,9 @@ photos_delete_item_job_run (PhotosDeleteItemJob *self,
   g_autoptr (PhotosQuery) query = NULL;
   PhotosSearchContextState *state;
 
+  g_return_if_fail (PHOTOS_IS_DELETE_ITEM_JOB (self));
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
+
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_delete_item_job_run);
 
