@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2013 Intel Corporation. All rights reserved.
- * Copyright © 2016 – 2019 Red Hat, Inc.
+ * Copyright © 2016 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ void                  photos_dlna_renderer_unshare            (PhotosDlnaRendere
                                                                GAsyncReadyCallback  callback,
                                                                gpointer             user_data);
 
-void                  photos_dlna_renderer_unshare_finish     (PhotosDlnaRenderer  *self,
+gboolean              photos_dlna_renderer_unshare_finish     (PhotosDlnaRenderer  *self,
                                                                GAsyncResult        *res,
                                                                GError             **error);
 
@@ -68,7 +68,7 @@ void                  photos_dlna_renderer_unshare_all        (PhotosDlnaRendere
                                                                GAsyncReadyCallback  callback,
                                                                gpointer             user_data);
 
-void                  photos_dlna_renderer_unshare_all_finish (PhotosDlnaRenderer  *self,
+gboolean              photos_dlna_renderer_unshare_all_finish (PhotosDlnaRenderer  *self,
                                                                GAsyncResult        *res,
                                                                GError             **error);
 
