@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib.h>
 #include <tracker-sparql.h>
 
@@ -52,11 +51,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PhotosOffsetController, photos_offset_controller, G_TYPE_OBJECT);
-DZL_DEFINE_COUNTER (instances,
-                    "PhotosOffsetController",
-                    "Instances",
-                    "Number of PhotosOffsetController instances")
-
 
 enum
 {
@@ -69,22 +63,24 @@ photos_offset_controller_cursor_next (GObject *source_object, GAsyncResult *res,
 {
   PhotosOffsetController *self;
   PhotosOffsetControllerPrivate *priv;
-  GError *error;
   TrackerSparqlCursor *cursor = TRACKER_SPARQL_CURSOR (source_object);
   gboolean success;
 
-  error = NULL;
-  /* Note that tracker_sparql_cursor_next_finish can return FALSE even without
-   * an error
-   */
-  success = tracker_sparql_cursor_next_finish (cursor, res, &error);
-  if (error != NULL)
-    {
-      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        g_warning ("Unable to query the item count: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    /* Note that tracker_sparql_cursor_next_finish can return FALSE even without
+     * an error
+     */
+    success = tracker_sparql_cursor_next_finish (cursor, res, &error);
+    if (error != NULL)
+      {
+        if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+          g_warning ("Unable to query the item count: %s", error->message);
+
+        goto out;
+      }
+  }
 
   self = PHOTOS_OFFSET_CONTROLLER (user_data);
   priv = photos_offset_controller_get_instance_private (self);
@@ -112,24 +108,25 @@ photos_offset_controller_reset_count_query_executed (GObject *source_object, GAs
   PhotosOffsetController *self = PHOTOS_OFFSET_CONTROLLER (user_data);
   PhotosOffsetControllerPrivate *priv;
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
-  TrackerSparqlCursor *cursor;
-  GError *error;
+  g_autoptr (TrackerSparqlCursor) cursor = NULL;
 
   priv = photos_offset_controller_get_instance_private (self);
 
-  error = NULL;
-  cursor = tracker_sparql_connection_query_finish (connection, res, &error);
-  if (error != NULL)
-    {
-      g_error_free (error);
-      return;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    cursor = tracker_sparql_connection_query_finish (connection, res, &error);
+    if (error != NULL)
+      goto out;
+  }
 
   tracker_sparql_cursor_next_async (cursor,
                                     priv->cancellable,
                                     photos_offset_controller_cursor_next,
                                     self);
-  g_object_unref (cursor);
+
+ out:
+  return;
 }
 
 
@@ -157,8 +154,6 @@ static void
 photos_offset_controller_finalize (GObject *object)
 {
   G_OBJECT_CLASS (photos_offset_controller_parent_class)->finalize (object);
-
-  DZL_COUNTER_DEC (instances);
 }
 
 
@@ -167,8 +162,6 @@ photos_offset_controller_init (PhotosOffsetController *self)
 {
   PhotosOffsetControllerPrivate *priv;
 
-  DZL_COUNTER_INC (instances);
-
   priv = photos_offset_controller_get_instance_private (self);
 
   priv->cancellable = g_cancellable_new ();
@@ -264,10 +257,13 @@ photos_offset_controller_increase_offset (PhotosOffsetController *self)
 
   remaining = photos_offset_controller_get_remaining (self);
   if (remaining <= 0)
-    return;
+    goto out;
 
   priv->offset += OFFSET_STEP;
   g_signal_emit (self, signals[OFFSET_CHANGED], 0, priv->offset);
+
+ out:
+  return;
 }
 
 
@@ -275,9 +271,9 @@ void
 photos_offset_controller_reset_count (PhotosOffsetController *self)
 {
   PhotosOffsetControllerPrivate *priv;
-  PhotosQuery *query = NULL;
+  g_autoptr (PhotosQuery) query = NULL;
   const gchar *type_name;
-  gchar *tag = NULL;
+  g_autofree gchar *tag = NULL;
 
   priv = photos_offset_controller_get_instance_private (self);
 
@@ -299,8 +295,7 @@ photos_offset_controller_reset_count (PhotosOffsetController *self)
                                g_object_unref);
 
  out:
-  g_clear_object (&query);
-  g_free (tag);
+  return;
 }
 
 
