@@ -22,7 +22,6 @@
 
 #include <string.h>
 
-#include <dazzle.h>
 #include <glib.h>
 
 #include "photos-debug.h"
@@ -52,8 +51,6 @@ static void photos_pipeline_async_initable_iface_init (GAsyncInitableIface *ifac
 
 G_DEFINE_TYPE_EXTENDED (PhotosPipeline, photos_pipeline, G_TYPE_OBJECT, 0,
                         G_IMPLEMENT_INTERFACE (G_TYPE_ASYNC_INITABLE, photos_pipeline_async_initable_iface_init));
-DZL_DEFINE_COUNTER (instances, "PhotosPipeline", "Instances", "Number of PhotosPipeline instances")
-
 
 static const gchar *OPERATIONS[] =
 {
@@ -294,8 +291,6 @@ photos_pipeline_finalize (GObject *object)
   g_free (self->snapshot);
 
   G_OBJECT_CLASS (photos_pipeline_parent_class)->finalize (object);
-
-  DZL_COUNTER_DEC (instances);
 }
 
 
@@ -329,8 +324,6 @@ photos_pipeline_set_property (GObject *object, guint prop_id, const GValue *valu
 static void
 photos_pipeline_init (PhotosPipeline *self)
 {
-  DZL_COUNTER_INC (instances);
-
   self->hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
   self->graph = gegl_node_new ();
 }
