@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #ifndef PHOTOS_SEARCH_TYPE_H
 #define PHOTOS_SEARCH_TYPE_H
 
-#include <glib-object.h>
+#include "photos-sparql-template.h"
 
 G_BEGIN_DECLS
 
@@ -35,12 +35,11 @@ G_DECLARE_FINAL_TYPE (PhotosSearchType, photos_search_type, PHOTOS, SEARCH_TYPE,
 #define PHOTOS_SEARCH_TYPE_STOCK_FAVORITES "favorites"
 #define PHOTOS_SEARCH_TYPE_STOCK_PHOTOS "photos"
 
-PhotosSearchType    *photos_search_type_new                (const gchar *id, const gchar *name);
-
-PhotosSearchType    *photos_search_type_new_full           (const gchar *id,
+PhotosSearchType    *photos_search_type_new                (const gchar *id,
                                                             const gchar *name,
-                                                            const gchar *where,
-                                                            const gchar *filter);
+                                                            PhotosSparqlTemplate *sparql_template);
+
+PhotosSparqlTemplate *photos_search_type_get_sparql_template (PhotosSearchType *self);
 
 G_END_DECLS
 
