@@ -2,7 +2,7 @@
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2015 Alessandro Bono
  * Copyright © 2014 Pranav Kant
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,12 +69,15 @@ photos_selection_toolbar_dialog_response (GtkDialog *dialog, gint response_id, g
   GVariant *new_state;
 
   if (response_id != GTK_RESPONSE_CLOSE)
-    return;
+    goto out;
 
   gtk_widget_destroy (GTK_WIDGET (dialog));
 
   new_state = g_variant_new ("b", FALSE);
   g_action_change_state (self->selection_mode_action, new_state);
+
+ out:
+  return;
 }
 
 
@@ -87,24 +90,27 @@ photos_selection_toolbar_collection_clicked (GtkButton *button, gpointer user_da
 
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
   if (!gtk_widget_is_toplevel (toplevel))
-    return;
+    goto out;
 
   dialog = photos_organize_collection_dialog_new (GTK_WINDOW (toplevel));
   gtk_widget_show_all (dialog);
   g_signal_connect (dialog, "response", G_CALLBACK (photos_selection_toolbar_dialog_response), self);
+
+ out:
+  return;
 }
 
 
 static void
 photos_selection_toolbar_delete (PhotosSelectionToolbar *self)
 {
-  GList *items = NULL;
+  g_autolist (PhotosBaseItem) items = NULL;
   GList *selection;
   GList *l;
   GVariant *new_state;
 
   if (!photos_utils_get_selection_mode ())
-    return;
+    goto out;
 
   selection = photos_selection_controller_get_selection (self->sel_cntrlr);
   for (l = selection; l != NULL; l = l->next)
@@ -130,7 +136,8 @@ photos_selection_toolbar_delete (PhotosSelectionToolbar *self)
   new_state = g_variant_new ("b", FALSE);
   g_action_change_state (self->selection_mode_action, new_state);
 
-  g_list_free_full (items, g_object_unref);
+ out:
+  return;
 }
 
 
@@ -146,13 +153,13 @@ static void
 photos_selection_toolbar_favorite_clicked (GtkButton *button, gpointer user_data)
 {
   PhotosSelectionToolbar *self = PHOTOS_SELECTION_TOOLBAR (user_data);
-  GList *items = NULL;
+  g_autolist (PhotosBaseItem) items = NULL;
   GList *selection;
   GList *l;
   GVariant *new_state;
 
   if (self->inside_refresh)
-    return;
+    goto out;
 
   selection = photos_selection_controller_get_selection (self->sel_cntrlr);
   for (l = selection; l != NULL; l = l->next)
@@ -181,7 +188,8 @@ photos_selection_toolbar_favorite_clicked (GtkButton *button, gpointer user_data
   new_state = g_variant_new ("b", FALSE);
   g_action_change_state (G_ACTION (self->selection_mode_action), new_state);
 
-  g_list_free_full (items, g_object_unref);
+ out:
+  return;
 }
 
 
@@ -195,8 +203,8 @@ photos_selection_toolbar_set_item_visibility (PhotosSelectionToolbar *self)
   gboolean has_selection;
   gboolean enable_collection;
   gboolean enable_favorite;
-  gchar *favorite_label;
-  gchar *open_label;
+  g_autofree gchar *favorite_label = NULL;
+  g_autofree gchar *open_label = NULL;
   guint fav_count = 0;
   guint sel_length = 0;
 
@@ -240,8 +248,6 @@ photos_selection_toolbar_set_item_visibility (PhotosSelectionToolbar *self)
     open_label = g_strdup (_("Open"));
 
   gtk_button_set_label (GTK_BUTTON (self->toolbar_open), open_label);
-  g_free (open_label);
-  g_list_free_full (apps, g_free);
 
   if (enable_favorite && fav_count == sel_length)
     {
@@ -256,12 +262,13 @@ photos_selection_toolbar_set_item_visibility (PhotosSelectionToolbar *self)
 
   gtk_button_set_image (GTK_BUTTON (self->toolbar_favorite), image);
   gtk_widget_set_tooltip_text (self->toolbar_favorite, favorite_label);
-  g_free (favorite_label);
 
   gtk_widget_set_sensitive (self->toolbar_collection, enable_collection);
   gtk_widget_set_sensitive (self->toolbar_favorite, enable_favorite);
 
   self->inside_refresh = FALSE;
+
+  g_list_free_full (apps, g_free);
 }
 
 
@@ -296,17 +303,20 @@ photos_selection_toolbar_selection_changed (PhotosSelectionToolbar *self)
   PhotosWindowMode mode;
 
   if (!photos_utils_get_selection_mode ())
-    return;
+    goto out;
 
   mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (mode == PHOTOS_WINDOW_MODE_IMPORT)
-    return;
+    goto out;
 
   selection = photos_selection_controller_get_selection (self->sel_cntrlr);
   photos_selection_toolbar_set_item_listeners (self, selection);
 
   photos_selection_toolbar_set_item_visibility (self);
   gtk_widget_show (GTK_WIDGET (self));
+
+ out:
+  return;
 }
 
 
