@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 
@@ -81,11 +80,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PhotosTrackerController, photos_tracker_controller, G_TYPE_OBJECT);
-DZL_DEFINE_COUNTER (instances,
-                    "PhotosTrackerController",
-                    "Instances",
-                    "Number of PhotosTrackerController instances")
-
 
 enum
 {
@@ -526,8 +520,6 @@ photos_tracker_controller_finalize (GObject *object)
   g_clear_error (&priv->queue_error);
 
   G_OBJECT_CLASS (photos_tracker_controller_parent_class)->finalize (object);
-
-  DZL_COUNTER_DEC (instances);
 }
 
 
@@ -563,8 +555,6 @@ photos_tracker_controller_init (PhotosTrackerController *self)
   GApplication *app;
   PhotosSearchContextState *state;
 
-  DZL_COUNTER_INC (instances);
-
   priv = photos_tracker_controller_get_instance_private (self);
 
   app = g_application_get_default ();
