@@ -37,8 +37,6 @@
 #include "photos-device-item.h"
 #include "photos-enums.h"
 #include "photos-error.h"
-#include "photos-facebook-item.h"
-#include "photos-flickr-item.h"
 #include "photos-gegl.h"
 #include "photos-google-item.h"
 #include "photos-local-item.h"
@@ -717,14 +715,12 @@ photos_utils_ensure_builtins (void)
   if (g_once_init_enter (&once_init_value))
     {
       g_type_ensure (PHOTOS_TYPE_DEVICE_ITEM);
-      g_type_ensure (PHOTOS_TYPE_FACEBOOK_ITEM);
-      g_type_ensure (PHOTOS_TYPE_FLICKR_ITEM);
-      g_type_ensure (PHOTOS_TYPE_GOOGLE_ITEM);
+      //g_type_ensure (PHOTOS_TYPE_GOOGLE_ITEM);
       g_type_ensure (PHOTOS_TYPE_LOCAL_ITEM);
       g_type_ensure (PHOTOS_TYPE_MEDIA_SERVER_ITEM);
 
       g_type_ensure (PHOTOS_TYPE_SHARE_POINT_EMAIL);
-      g_type_ensure (PHOTOS_TYPE_SHARE_POINT_GOOGLE);
+      //g_type_ensure (PHOTOS_TYPE_SHARE_POINT_GOOGLE);
 
       g_type_ensure (PHOTOS_TYPE_TOOL_COLORS);
       g_type_ensure (PHOTOS_TYPE_TOOL_CROP);
