@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  * Copyright © 2017 Umang Jain
  *
  * This program is free software: you can redistribute it and/or modify
@@ -154,8 +154,7 @@ photos_view_container_item_activated (PhotosViewContainer *self, GdMainBoxItem *
   item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (self->item_mngr, id));
   g_return_if_fail ((gpointer) box_item == (gpointer) item);
 
-  if (!photos_base_item_is_collection (item) &&
-      photos_remote_display_manager_is_active (self->remote_mngr))
+  if (!photos_base_item_is_collection (item) && photos_remote_display_manager_is_active (self->remote_mngr))
     photos_remote_display_manager_render (self->remote_mngr, item);
   else
     photos_base_manager_set_active_object (self->item_mngr, G_OBJECT (item));
@@ -205,12 +204,15 @@ photos_view_container_select_all (PhotosViewContainer *self)
 
   mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (self->mode != mode)
-    return;
+    goto out;
 
   new_state = g_variant_new ("b", TRUE);
   g_action_change_state (self->selection_mode_action, new_state);
 
   gd_main_box_select_all (GD_MAIN_BOX (self->view));
+
+ out:
+  return;
 }
 
 
@@ -221,9 +223,12 @@ photos_view_container_select_none (PhotosViewContainer *self)
 
   mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (self->mode != mode)
-    return;
+    goto out;
 
   gd_main_box_unselect_all (GD_MAIN_BOX (self->view));
+
+ out:
+  return;
 }
 
 
@@ -241,14 +246,13 @@ static void
 photos_view_container_selection_changed (PhotosViewContainer *self)
 {
   GList *selected_urns;
-  GList *selection;
+  g_autolist (GdMainBoxItem) selection = NULL;
 
   selection = gd_main_box_get_selection (GD_MAIN_BOX (self->view));
   selected_urns = photos_utils_get_urns_from_items (selection);
   photos_selection_controller_set_selection (self->sel_cntrlr, selected_urns);
 
   g_list_free_full (selected_urns, g_free);
-  g_list_free_full (selection, g_object_unref);
 }
 
 
@@ -259,9 +263,12 @@ photos_view_container_set_selection_mode (PhotosViewContainer *self, gboolean se
 
   window_mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (self->mode != window_mode)
-    return;
+    goto out;
 
   gd_main_box_set_selection_mode (GD_MAIN_BOX (self->view), selection_mode);
+
+ out:
+  return;
 }
 
 
@@ -549,6 +556,8 @@ photos_view_container_activate_result (PhotosViewContainer *self)
   PhotosBaseItem *item;
   PhotosBaseManager *item_mngr_chld;
 
+  g_return_if_fail (PHOTOS_IS_VIEW_CONTAINER (self));
+
   item_mngr_chld = photos_item_manager_get_for_mode (PHOTOS_ITEM_MANAGER (self->item_mngr), self->mode);
   item = PHOTOS_BASE_ITEM (g_list_model_get_object (G_LIST_MODEL (item_mngr_chld), 0));
   photos_base_manager_set_active_object (self->item_mngr, G_OBJECT (item));
@@ -558,5 +567,6 @@ photos_view_container_activate_result (PhotosViewContainer *self)
 const gchar *
 photos_view_container_get_name (PhotosViewContainer *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_VIEW_CONTAINER (self), NULL);
   return self->name;
 }
